Processor.App.OutStreamer.stream\_to\_file.OutStreamerFileHTMLContent.get\_file\_name
=====================================================================================

.. currentmodule:: Processor.App.OutStreamer.stream_to_file

.. automethod:: OutStreamerFileHTMLContent.get_file_name